# PyPI Package

This release is available on PyPI:

- **Package:** [ekfsm v1.12.0-alpha.8](https://pypi.org/project/ekfsm/1.12.0-alpha.8/)
- **Installation:** `pip install ekfsm==1.12.0-alpha.8`

## Alternative Installations

- **Latest stable:** `pip install ekfsm`
- **From source:** `pip install git+https://gitlab.com/path/to/ekfsm@v1.12.0-alpha.8`
